<p align='left'>
  <picture>
    <!-- light mode logo -->
    <source media="(prefers-color-scheme: light)" srcset="https://raw.githubusercontent.com/EasyScience/EasyCrystallography/master/resources/logo/EasyCrystallography-logo_lightmode.svg">
    <!-- dark mode logo -->
    <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/EasyScience/EasyCrystallography/master/resources/logo/EasyCrystallography-logo_darkmode.svg">
    <!-- default logo == light mode logo -->
    <img src="https://raw.githubusercontent.com/EasyScience/EasyCrystallography/master/resources/logo/EasyCrystallography-logo_lightmode.svg" alt="EasyCrystallography">
  </picture>
</p>

**EasyCrystallography** is a Python library used within the [EasyScience]
framework to generate and manipulate crystal structures.

## Useful Links

- [Documentation] - Access the full documentation.
- [Issue Tracker] - Report bugs or request new features.
- [Source Code] - Explore the source code repository.

## Contributing

We welcome contributions! Our vision is for **EasyCrystallography** to be a
community-driven, open-source project supported by a diverse group of
contributors.

The project is currently maintained by the [European Spallation Source (ESS)] in
Sweden.

If you'd like to contribute, please refer to our [Contributing Guidelines] for
information about our code of conduct and instructions on submitting pull
requests.

## License

**EasyCrystallography** is licensed under the [BSD 3-Clause License].

<!-- prettier-ignore-start -->
[BSD 3-Clause License]: https://github.com/EasyScience/EasyCrystallography/blob/master/LICENSE
[Contributing Guidelines]: https://github.com/EasyScience/EasyCrystallography/blob/master/CONTRIBUTING.md
[EasyScience]: https://easyscience.software
[European Spallation Source (ESS)]: https://ess.eu
[Documentation]: https://easyscience.github.io/EasyCrystallography
[Issue Tracker]: https://github.com/EasyScience/EasyCrystallography/issues
[Source Code]: https://github.com/EasyScience/EasyCrystallography
<!-- prettier-ignore-end -->
